==> aws-java-sdk-lambda-1.10.61-sources.jar: com/amazonaws/services/lambda/model/transform/InvokeAsyncResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.lambda.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.lambda.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * Invoke Async Result JSON Unmarshaller
 */
public class InvokeAsyncResultJsonUnmarshaller implements Unmarshaller<InvokeAsyncResult, JsonUnmarshallerContext> {

    public InvokeAsyncResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        InvokeAsyncResult invokeAsyncResult = new InvokeAsyncResult();

        invokeAsyncResult.setStatus(context.getHttpResponse().getStatusCode());
        return invokeAsyncResult;
    }

    private static InvokeAsyncResultJsonUnmarshaller instance;
    public static InvokeAsyncResultJsonUnmarshaller getInstance() {
        if (instance == null) instance = new InvokeAsyncResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-lambda-1.11.7-sources.jar: com/amazonaws/services/lambda/model/transform/InvokeAsyncResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.lambda.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.lambda.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * InvokeAsyncResult JSON Unmarshaller
 */
public class InvokeAsyncResultJsonUnmarshaller implements
        Unmarshaller<InvokeAsyncResult, JsonUnmarshallerContext> {

    public InvokeAsyncResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        InvokeAsyncResult invokeAsyncResult = new InvokeAsyncResult();

        invokeAsyncResult.setStatus(context.getHttpResponse().getStatusCode());

        return invokeAsyncResult;
    }

    private static InvokeAsyncResultJsonUnmarshaller instance;

    public static InvokeAsyncResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new InvokeAsyncResultJsonUnmarshaller();
        return instance;
    }
}
